@@ -35,7 +35,7 @@ ldp <- function(G, H, tol=sqrt(.Machine$double.eps),
          W=as.double(rep(0.,NW)),xIndex=as.integer(rep(0,Nin)),
          Mode=as.integer(0),
          verbose=as.logical(verbose),IsError=as.logical(IsError),
-         iter=as.integer(0))
+         iter=as.integer(0), PACKAGE='limSolve')
   IsError<-sol$IsError 
   
   ## The solution
